userelaina - rsap2p
====================================

.. image:: https://img.shields.io/pypi/v/rsap2p.svg
   :target: https://pypi.org/project/rsap2p/

Decentralized end-to-end encrypted communication tool.

You can use pip to install packages from the `Python Package Index`_ and other indexes.

* `GitHub page`_
* `Issue tracking`_

.. _Python Package Index: https://pypi.org
.. _GitHub page: https://github.com/userelaina/rsap2p
.. _Issue tracking: https://github.com/userelaina/rsap2p/issues
